| Title: | Create Interface for 'RBMI' and 'tern' |
|---|---|
| Description: | 'RBMI' implements standard and reference based multiple imputation methods for continuous longitudinal endpoints (Gower-Page et al. (2022) <doi:10.21105/joss.04251>). This package provides an interface for 'RBMI' uses the 'tern' <https://cran.r-project.org/package=tern> framework by Zhu et al. (2023) and tabulate results easily using 'rtables' <https://cran.r-project.org/package=rtables> by Becker et al. (2023). |
| Authors: | Joe Zhu [aut, cre] (ORCID: <https://orcid.org/0000-0001-7566-2787>), Jana Stoilova [aut], F. Hoffmann-La Roche AG [cph, fnd] |
| Maintainer: | Joe Zhu <[email protected]> |
| License: | Apache License 2.0 |
| Version: | 0.1.6.9000 |
| Built: | 2026-05-21 03:20:02 UTC |
| Source: | https://github.com/insightsengineering/tern.rbmi |
rtables::make_afun() on it. It is used as afun in rtables::analyze().a_rbmi_lsmeans(df, .in_ref_col, show_relative = c("reduction", "increase"))a_rbmi_lsmeans(df, .in_ref_col, show_relative = c("reduction", "increase"))
df |
input dataframe |
.in_ref_col |
boolean variable, if reference column is specified |
show_relative |
"reduction" if ( |
Formatted Analysis function
h_tidy_pool(x)h_tidy_pool(x)
x |
( |
Data frame with results of pool for a single visit.
data("rbmi_test_data") pool_obj <- rbmi_test_data h_tidy_pool(pool_obj$pars[1:3])data("rbmi_test_data") pool_obj <- rbmi_test_data h_tidy_pool(pool_obj$pars[1:3])
tern.rbmi package. This is an pool object from the rbmi analysis, see
browseVignettes(package = "tern.rbmi")
rbmi_test_datarbmi_test_data
An object of class pool of length 5.
s_rbmi_lsmeans(df, .in_ref_col, show_relative = c("reduction", "increase"))s_rbmi_lsmeans(df, .in_ref_col, show_relative = c("reduction", "increase"))
df |
input dataframe |
.in_ref_col |
boolean variable, if reference column is specified |
show_relative |
"reduction" if ( |
A list of statistics extracted from a tidied LS means data frame.
library(rtables) library(dplyr) library(broom) data("rbmi_test_data") pool_obj <- rbmi_test_data df <- tidy(pool_obj) s_rbmi_lsmeans(df[1, ], .in_ref_col = TRUE) s_rbmi_lsmeans(df[2, ], .in_ref_col = FALSE)library(rtables) library(dplyr) library(broom) data("rbmi_test_data") pool_obj <- rbmi_test_data df <- tidy(pool_obj) s_rbmi_lsmeans(df[1, ], .in_ref_col = TRUE) s_rbmi_lsmeans(df[2, ], .in_ref_col = FALSE)
rbmi pool results.summarize_rbmi( lyt, ..., table_names = "rbmi_summary", .stats = NULL, .formats = NULL, .indent_mods = NULL, .labels = NULL )summarize_rbmi( lyt, ..., table_names = "rbmi_summary", .stats = NULL, .formats = NULL, .indent_mods = NULL, .labels = NULL )
lyt |
( |
... |
additional argument. |
table_names |
( |
.stats |
( |
.formats |
(named |
.indent_mods |
(named |
.labels |
(named |
rtables layout for tabulating LS means estimates from tidied
rbmi pool results.
library(rtables) library(dplyr) library(broom) data("rbmi_test_data") pool_obj <- rbmi_test_data df <- tidy(pool_obj) basic_table() %>% split_cols_by("group", ref_group = levels(df$group)[1]) %>% split_rows_by("visit", split_label = "Visit", label_pos = "topleft") %>% summarize_rbmi() %>% build_table(df)library(rtables) library(dplyr) library(broom) data("rbmi_test_data") pool_obj <- rbmi_test_data df <- tidy(pool_obj) basic_table() %>% split_cols_by("group", ref_group = levels(df$group)[1]) %>% split_rows_by("visit", split_label = "Visit", label_pos = "topleft") %>% summarize_rbmi() %>% build_table(df)
broom::tidy()) to prepare a data frame from an
pool rbmi object containing the LS means and contrasts and multiple visits## S3 method for class 'pool' tidy(x, ...)## S3 method for class 'pool' tidy(x, ...)
x |
( |
... |
Additional arguments. Not used. Needed to match generic signature only. |
A dataframe